@@ -5,13 +5,11 @@ Portions Copyright (c) 2021 InnoGames GmbH
 Portions Copyright (c) 2021 Emre Hasegeli
 """
 
-import logging
 from fileinput import input
-from sys import stdout
+from sys import stdout, stderr
+from traceback import print_exc
 
-from scutils import log_init
-
-from githooks.base_check import CheckState, prepare_checks
+from githooks.base_check import CheckState, prepare_checks, BaseCheck
 from githooks.checks import checks
 from githooks.config import config
 from githooks.git import Commit
@@ -24,6 +22,15 @@ class Runner(object):
         self.changed_file_checks = dict()
 
     def run(self):
+        # check whether commit check is enabled
+        commit_check_is_enabled = False
+        try:
+            commit_check_is_enabled = config.get("commit_check.enabled")
+        except:
+            pass
+        if not commit_check_is_enabled:
+            return CheckState.DONE
+
         state = CheckState.NEW
 
         # We are buffering the checks to let them run parallel in
@@ -37,7 +44,6 @@ class Runner(object):
             dev_mode = config.get("dev.dev_mode")
         except:
             pass
-        logging.getLogger(__name__).info('program is running in development mode: {}'.format(dev_mode))
         if dev_mode:
             for check in self.expand_checks(checks):
                 check.print_problems()
@@ -134,13 +140,15 @@ class Runner(object):
 
 def main():
     try:
-        log_init()
         state = Runner().run()
     except Exception as e:
         # Flush the problems we have printed so far to avoid the traceback
         # appearing in between them.
         stdout.flush()
-        logging.getLogger(__name__).exception('An error occurred.', exc_info=e)
+        print(file=stderr)
+        print('{} An error occurred: {}'.format(BaseCheck.ERROR_MSG_PREFIX, e), file=stderr)
+        print_exc()
+        return 1
     else:
         if state >= CheckState.FAILED:
             return 1
